// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "libretranslatetranslator_debug.h"


Q_LOGGING_CATEGORY(TRANSLATOR_LIBRETRANSLATE_LOG, "org.kde.kf.texttranslator.libretranslate", QtInfoMsg)

