// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "autogeneratetext_ollama_generate_json_debug.h"


Q_LOGGING_CATEGORY(AUTOGENERATETEXT_OLLAMA_GENERATE_JSON_LOG, "org.kde.kf.autogeneratetext.ollama_json", QtInfoMsg)

